@@ -1,19 +1,19 @@
 """Errors used in this library."""
 
-class FireServiceRotaError(Exception):
-    """Base class for all fireservicerota exceptions."""
-    pass
 
-
-class ExpiredTokenError(FireServiceRotaError):
+class ExpiredTokenError(Exception):
     """Raised when fireservicerota API returns a code indicating expired tokens."""
+
     pass
 
 
-class InvalidTokenError(FireServiceRotaError):
+class InvalidTokenError(Exception):
     """Raised when fireservicerota API returns a code indicating invalid tokens."""
+
     pass
 
 
-class InvalidAuthError(FireServiceRotaError):
+class InvalidAuthError(Exception):
     """Raised when fireservicerota API returns a code indicating invalid credentials."""
+
+    pass
